==> glog-1.00.tar.gz: glog-1.00/adventure.php <==
<?php
# Show all entries in an adventure
#
# $Id: adventure.php,v 1.2 2004/03/11 14:45:16 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	$adv = "NoAdv";
	if (isset($_SERVER["PATH_INFO"])) {
		$adv = ereg_replace("[^A-Za-z_]","",$_SERVER["PATH_INFO"]);
	}
	if (!strlen($adv))
		$adv = "NoAdv";

	$adventures = load_adventures();

	$title = "";
	if (isset($adventures[$adv]))
		$title .= " / " . htmlspecialchars($adventures[$adv]["title"]);

	html_begin($title);

	if (isset($adventures[$adv])) {
		print "<h4>".htmlspecialchars($adventures[$adv]["title"])."</h4>\n";
		foreach ($adventures[$adv]["dates"] as $i => $date) {
			if (isset($days[$date])) {
				$text = implode('', file(get_filename($date)));
				print_day($date, $text);
			} else {
				print "<h5>No entries found for ({$date})</h5><br />\n";
			}
		}
	} else {
		print "<h5>No entries found</h5><br />\n";
	}

	html_end();
?>

==> glog-2.00.tar.gz: glog-2.00/adventure.php <==
<?php
# Show all entries in an adventure
#
# $Id: adventure.php,v 1.3 2004/06/01 01:25:14 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	$adv = "NoAdv";
	if (isset($_SERVER["PATH_INFO"])) {
		$adv = ereg_replace("[^A-Za-z0-9_]","",$_SERVER["PATH_INFO"]);
	}
	if (!strlen($adv))
		$adv = "NoAdv";

	$adventures = load_adventures();

	$title = "";
	if (isset($adventures[$adv]))
		$title .= " / " . htmlspecialchars($adventures[$adv]["title"]);

	html_begin($title);

	if (isset($adventures[$adv])) {
		print "<h4>".htmlspecialchars($adventures[$adv]["title"])."</h4>\n";
		foreach ($adventures[$adv]["dates"] as $i => $date) {
			if (isset($days[$date])) {
				$text = implode('', file(get_filename($date)));
				print_day($date, $text);
			} else {
				print "<h5>No entries found for ({$date})</h5><br />\n";
			}
		}
	} else {
		print "<h5>No entries found</h5><br />\n";
	}

	html_end();
?>
